#!/usr/bin/perl
# not yet finished
#
use FileHandle;


my $file = FileHandle->new();
my $header = FileHandle->new();

$file->open("skk-rom-kana-base-rule-list","r") or die "Can't open\n";
$header->open("skkconv_kana_private.h","w") or die "Can't open\n";

$header->print(header_init ());
$header->print ("SkkConvRuleItem baselist[] = {\n");
while (my $line = $file->getline())
{
	my $res = "";
	if ($res = parse_normal ($line)) {
		$header->print ($res);
	} elsif ($res = parse_normal_same ($line)) {
		$header->print ($res);
	} elsif ($res = parse_func ($line)) {
		$header->print ($res);
	}
}
$header->print ("};\n");
$header->print(header_end ());

$file->close();
$header->close();


sub parse_normal ($)
{
	my $ref = shift;
	my $append;
	$ref =~ m/\"(.+)\" (.+) \(\"(.+)\" \. \"(.+)\"\)\)/;
	if ($1 && $2 && $3 && $4) {
		if ($2 eq "nil") {
			$append = "NULL";
		} else {
			$append = $2;
		}
		return qq|	{	"$1",	$append,	"$3",	"$4",	SKKCONV_TYPE_NORMAL	},\n|;
	}
	return undef;
}

sub parse_normal_same ($)
{
	my $ref = shift;
	my $append;
	$ref =~ m/\"(.+)\" (.+) \"(.+)\"\)/;
	if ($1 && $2 && $3) {
		if ($2 eq "nil") {
			$append = "NULL";
		} else {
			$append = $2;
		}
		return qq|	{	"$1",	$append,	"$3",	"$3",	SKKCONV_TYPE_NORMAL	},\n|;
	}
	return undef;
}

sub parse_func ($)
{
	my $ref = shift;
	my $append;
	$ref =~ m/\"(.+)\" (.+) (.+)\)/;
	if ($1 && $2 && $3) {
		if ($2 eq "nil") {
			$append = "NULL";
		} else {
			$append = $2;
		}
		return qq|	{	"$1",	$append,	"$3",	"NULL",	SKKCONV_TYPE_FUNC\t},\n|;
	}
	return undef;
}

sub header_init ()
{
	return <<'EOF';
/*
 * LibSKK, a tiny Library to emulate SKK (Simple Kana Kanji Conversion)
 * 
 * Copyright (C) 2002 Motonobu Ichimura <famao@kondara.org>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL
 * INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */

/* $Id: $ */

/* vi:set ts=4 sw=4: */


#ifndef SKKCONV_KANA_PRIVATE_H
#define SKKCONV_KANA_PRIVATE_H
#include <glib.h>

#include <skkconv_kana.h>

/* This file is generated from skk.el (skk-rom-kana-base-rule-list) */

EOF
}

sub header_end ()
{
	return <<'EOF';

#endif /* SKKCONV_KANA_PRIVATE_H */
EOF
}
